ProtectionLevel enum
The data channel protection level for FTPS sessions (RFC 4217 9).
Set via the PROT command after AUTH TLS and PBSZ 0.
Values
- clear → const ProtectionLevel
-
Clear (unencrypted) data channel. Set via
PROT C. - private_ → const ProtectionLevel
-
Private (TLS-encrypted) data channel. Set via
PROT P.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ProtectionLevel> - A constant List of the values in this enum, in order of their declaration.