FTPCommandHandler class

Constructors

FTPCommandHandler(LoggerHandler logger)

Properties

hashCode int
The hash code for this object.
no setterinherited
logger LoggerHandler
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

handleAcct(String argument, FtpSession session) → void
ACCT: Provide account information (RFC 959). This server does not use accounts, so the command is accepted as superfluous. The argument is validated for non-empty syntax.
handleAllo(String argument, FtpSession session) → void
ALLO: Reserve storage space (RFC 959). This server does not require pre-allocation, so the command is accepted as a no-op. The argument (byte count) is validated for correct syntax. Optional second argument form: ALLO <bytes> R <record-size>
handleAuth(String argument, FtpSession session) Future<void>
AUTH: Authenticate / negotiate TLS (RFC 4217 4, RFC 2228).
handleCommand(String commandLine, FtpSession session) Future<void>
handleCurPath(FtpSession session) → void
handleEpsv(String argument, FtpSession session) Future<void>
handleFeat(FtpSession session) → void
handleHelp(FtpSession session) → void
handleMode(String argument, FtpSession session) → void
handleOptions(String argument, FtpSession session) → void
handlePass(String argument, FtpSession session) → void
handlePbsz(String argument, FtpSession session) → void
PBSZ: Protection Buffer Size (RFC 4217 8). For TLS, must be 0.
handleProt(String argument, FtpSession session) → void
PROT: Data Channel Protection Level (RFC 4217 9).
handleQuit(FtpSession session) Future<void>
handleRein(FtpSession session) → void
REIN: Reinitialize session (RFC 959). Flushes all user/account information and transfer parameters. Any transfer in progress is allowed to complete. The control connection remains open for a new USER command.
handleRename(String argument, FtpSession session) Future<void>
handleRnfr(String argument, FtpSession session) → void
handleRnto(String argument, FtpSession session) Future<void>
handleSite(String argument, FtpSession session) → void
SITE: Execute site-specific commands (RFC 959). This server does not implement any site-specific commands.
handleStat(String argument, FtpSession session) Future<void>
STAT: Return server status or file/directory info (RFC 959 4.1.3). Without arguments: returns general server status (211). With a pathname: returns a directory listing over the control connection.
handleStru(String argument, FtpSession session) → void
handleType(String argument, FtpSession session) → void
handleUser(String argument, FtpSession session) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited